@@ -682,8 +682,9 @@ class GrocyApiClient(object):
         if parsed_json:
             return RecipeDetailsResponse(parsed_json)
 
-    def add_generic(self, entity_type: str, data: object):
-        self._do_post_request(f"objects/{entity_type}", data)
+    def add_generic(self, entity_type: str, data: dict):
+        response = self._do_post_request(f"objects/{entity_type}", data)
+        return response.get("created_object_id")
 
     def delete_entity(self, entity_type: str, id):
         self._do_delete_request(f"objects/{entity_type}/{id}")
